# -*- coding: utf-8 -*-
# Generated by Django 1.9.8 on 2016-07-24 15:56
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_simple_files', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='files',
            name='enabled',
            field=models.BooleanField(default=True, verbose_name='使用中'),
        ),
    ]
